==> mythbuntu-log-grabber_0.1.orig.tar.gz: mythbuntu-log-grabber-0.1/setup.py <==
#!/usr/bin/python
# Mythbuntu-Log-Grabber install script
# Copyright (C) 2008, Nick Fox <nfox@foxmediasystems.com>
#
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

from distutils.core import setup

import subprocess, glob, os.path

setup(
    name="mythbuntu-log-grabber",
    author="Nick Fox",
    author_email="nfox@foxmediasystems.com",
    maintainer="Ubuntu MythTV Team",
    maintainer_email="ubuntu-mythtv@lists.ubuntu.com",
    url="http://www.mythbuntu.org",
    license="gpl",
    description="grabs logs to help troubleshooting efforts",
    packages=["MythbuntuLogGrabber"],
    data_files=[("share/mythbuntu-log-grabber", glob.glob("MythbuntuLogGrabber/*.glade")),
                ("share/mythbuntu-log-grabber", glob.glob("MythbuntuLogGrabber/*.py")),
                ("share/mythbuntu-log-grabber/bin", glob.glob("bin/mythbuntu-log-grabber")),
                ("share/applications", glob.glob("applications/*.desktop")),
		        ("share/mythbuntu-log-grabber", glob.glob("MythbuntuLogGrabber/*.png")),
                ("share/mythtv", glob.glob("mythtv/*.xml"))],
    scripts=["mythbuntu-log-grabber"],
)

==> mythbuntu-log-grabber_0.3.orig.tar.gz: mythbuntu-log-grabber-0.3/setup.py <==
#!/usr/bin/python
# Mythbuntu-Log-Grabber install script
# Copyright (C) 2008, Nick Fox <nfox@foxmediasystems.com>
#
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

from distutils.core import setup

import subprocess, glob, os.path

setup(
    name="mythbuntu-log-grabber",
    author="Nick Fox",
    author_email="nfox@foxmediasystems.com",
    maintainer="Ubuntu MythTV Team",
    maintainer_email="ubuntu-mythtv@lists.ubuntu.com",
    url="http://www.mythbuntu.org",
    license="gpl",
    description="grabs logs to help troubleshooting efforts",
    packages=["MythbuntuLogGrabber"],
    data_files=[("share/mythbuntu-log-grabber", glob.glob("MythbuntuLogGrabber/*.glade")),
                ("share/applications", glob.glob("applications/*.desktop")),
		("share/mythbuntu-log-grabber", glob.glob("MythbuntuLogGrabber/*.png")),
                ("share/mythtv", glob.glob("mythtv/*.xml"))],
    scripts=["bin/mythbuntu-log-grabber"],
)
